==> ndla-video-search-0.2.3.tgz: package/es/VideoSearchResultBrightcove.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import React from 'react';
import PropTypes from 'prop-types';
import { Button, LicenseByline } from 'ndla-ui';
import { getLicenseByNBTitle } from 'ndla-licenses';
import BEMHelper from 'react-bem-helper';
import PreviewVideo from './PreviewVideo';
import { LicenseShape, BrightcoveShape } from './shapes';

var classes = new BEMHelper({
  name: 'video-search',
  prefix: 'c-'
});

export default function VideoSearchResultBrightcove(_ref) {
  var video = _ref.video,
      onVideoPreview = _ref.onVideoPreview,
      selectedVideo = _ref.selectedVideo,
      onSelectVideo = _ref.onSelectVideo,
      locale = _ref.locale,
      translations = _ref.translations;

  var active = selectedVideo && selectedVideo.id === video.id ? 'active' : '';
  var license = getLicenseByNBTitle(video.custom_fields.license, locale);

  return React.createElement(
    'div',
    _extends({ key: video.id }, classes('list-item', active)),
    React.createElement(
      'div',
      classes('list-item-inner'),
      React.createElement('img', {
        role: 'presentation',
        alt: 'presentation',
        src: video.images.thumbnail.src
      }),
      React.createElement(
        'div',
        classes('information'),
        React.createElement(
          'h2',
          null,
          video.name
        ),
        React.createElement(
          'div',
          classes('copyright-author'),
          video.custom_fields.licenseinfo
        ),
        React.createElement(
          'div',
          classes('license'),
          license.rights ? React.createElement(LicenseByline, { licenseRights: license.rights }) : license
        ),
        React.createElement(
          Button,
          _extends({}, classes('button'), {
            outline: true,
            onClick: function onClick() {
              return onVideoPreview(video);
            } }),
          translations.previewVideo
        ),
        React.createElement(
          Button,
          _extends({}, classes('button'), { onClick: function onClick() {
              return onSelectVideo(video);
            } }),
          translations.addVideo
        )
      )
    ),
    selectedVideo && selectedVideo.id === video.id ? React.createElement(
      PreviewVideo,
      { onVideoPreview: onVideoPreview, selectedType: 'brightcove' },
      React.createElement('iframe', {
        className: 'c-video-preview__video',
        title: selectedVideo.name,
        src: '//players.brightcove.net/' + selectedVideo.account_id + '/BkLm8fT_default/index.html?videoId=' + selectedVideo.id,
        allowFullScreen: true
      })
    ) : ''
  );
}

VideoSearchResultBrightcove.propTypes = {
  license: LicenseShape,
  video: BrightcoveShape.isRequired,
  onVideoPreview: PropTypes.func.isRequired,
  selectedVideo: BrightcoveShape,
  onSelectVideo: PropTypes.func.isRequired,
  locale: PropTypes.string.isRequired,
  translations: PropTypes.shape({
    addVideo: PropTypes.string.isRequired,
    previewVideo: PropTypes.string.isRequired
  })
};

==> ndla-video-search-0.5.0-0.tgz: package/es/VideoSearchResultBrightcove.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import React from 'react';
import PropTypes from 'prop-types';
import { LicenseByline } from 'ndla-ui';
import Button from 'ndla-button';
import { getLicenseByNBTitle } from 'ndla-licenses';
import BEMHelper from 'react-bem-helper';
import PreviewVideo from './PreviewVideo';
import { LicenseShape, BrightcoveShape } from './shapes';

var classes = new BEMHelper({
  name: 'video-search',
  prefix: 'c-'
});

export default function VideoSearchResultBrightcove(_ref) {
  var video = _ref.video,
      onVideoPreview = _ref.onVideoPreview,
      selectedVideo = _ref.selectedVideo,
      onSelectVideo = _ref.onSelectVideo,
      locale = _ref.locale,
      translations = _ref.translations;

  var active = selectedVideo && selectedVideo.id === video.id ? 'active' : '';
  var license = video.custom_fields && video.custom_fields.license ? getLicenseByNBTitle(video.custom_fields.license, locale) : '';
  var thumbnailSource = video.images && video.images.thumbnail ? video.images.thumbnail.src : '';
  return React.createElement(
    'div',
    _extends({ key: video.id }, classes('list-item', active)),
    React.createElement(
      'div',
      classes('list-item-inner'),
      React.createElement('img', { role: 'presentation', alt: 'presentation', src: thumbnailSource }),
      React.createElement(
        'div',
        classes('information'),
        React.createElement(
          'h2',
          null,
          video.name || ''
        ),
        React.createElement(
          'div',
          classes('copyright-author'),
          video.custom_fields && video.custom_fields.licenseinfo ? video.custom_fields.licenseinfo : ''
        ),
        React.createElement(
          'div',
          classes('license'),
          license.rights ? React.createElement(LicenseByline, { licenseRights: license.rights }) : license
        ),
        React.createElement(
          Button,
          _extends({}, classes('button'), {
            outline: true,
            onClick: function onClick() {
              return onVideoPreview(video);
            } }),
          translations.previewVideo
        ),
        React.createElement(
          Button,
          _extends({}, classes('button'), { onClick: function onClick() {
              return onSelectVideo(video);
            } }),
          translations.addVideo
        )
      )
    ),
    selectedVideo && selectedVideo.id === video.id ? React.createElement(
      PreviewVideo,
      { onVideoPreview: onVideoPreview, selectedType: 'brightcove' },
      React.createElement('iframe', {
        className: 'c-video-preview__video',
        title: selectedVideo.name,
        src: '//players.brightcove.net/' + selectedVideo.account_id + '/BkLm8fT_default/index.html?videoId=' + selectedVideo.id,
        allowFullScreen: true
      })
    ) : ''
  );
}

VideoSearchResultBrightcove.propTypes = {
  license: LicenseShape,
  video: BrightcoveShape.isRequired,
  onVideoPreview: PropTypes.func.isRequired,
  selectedVideo: BrightcoveShape,
  onSelectVideo: PropTypes.func.isRequired,
  locale: PropTypes.string.isRequired,
  translations: PropTypes.shape({
    addVideo: PropTypes.string.isRequired,
    previewVideo: PropTypes.string.isRequired
  })
};
